SmartFallbackChain

Struct SmartFallbackChain 

pub struct SmartFallbackChain<'a> { /* private fields */ }
Smart fallback chain orchestrator.

Tries each TransportTarget in order, checking circuit breaker health before each attempt. Records all attempts in a FallbackNegotiationHistory.

Implementations

Source

impl<'a> SmartFallbackChain<'a>

pub fn new( client: &'a Client, health_tracker: &'a TransportHealthTracker, per_attempt_timeout: Duration, total_timeout: Duration, ) -> Self

Create a new fallback chain.

pub fn with_stdio(&self, command: String) -> Result<Self, String>

Enable stdio fallback with the given command.

pub async fn execute( &self, targets: &[TransportTarget], body: Bytes, headers: &HeaderMap, ) -> Result<SmartFallbackResult, SmartFallbackError>

Execute the fallback chain, trying each target in order.